.. default-role:: py:obj

FactorioCalc |version|
======================

.. include:: description.rst

.. toctree::
   :caption: Contents
   :maxdepth: 3

   comparison

   guide

   reference

   README <readme>

   ChangeLog

.. toctree::
   :caption: Indices and tables

   genindex


